@@ -220,8 +220,8 @@ class Swagger(object):
         for k, v in self.definitions.items():
             dds[k] = v.todict()
         d['components'] = {'schemas': dds}
-        d['tags'] = dict(map(lambda x: x.todict(), self.tags))
-        d['servers'] = dict(map(lambda x: x.todict(), self.servers)) # py2 vs py3
+        d['tags'] = list(map(lambda x: x.todict(), self.tags))
+        d['servers'] = list(map(lambda x: x.todict(), self.servers)) # py2 vs py3
         if self.info:
             d['info'] = self.info.todict()
         return d
