@@ -34,11 +34,12 @@ vlogs = {
     '0.3.1': 'auto load .env',
     '0.3.2': 'fix load .env',
     '0.3.3': 'add any router',
-    '0.3.4': 'add python3 support'
+    '0.3.4': 'add python3 support',
+    '0.3.5': 'fix swagger tags/servers'
 }
 
 name = 'm2c'
-version = '0.3.4'
+version = '0.3.5'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
